"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = require("fs");
var path_1 = require("path");
var React = require("react");
var ReactDOMServer = require("react-dom/server");
var typestyle_1 = require("typestyle");
var page_1 = require("./renderer/page");
var pageModel_1 = require("./renderer/pageModel");
var renderPageHtml = function (title, body, inlineStyles) { return "<!DOCTYPE html>\n<html>\n    <head>\n        <meta charset=\"utf-8\" />\n        <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge\">\n        <title>" + title + "</title>\n        <meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">\n        <style>" + inlineStyles + "</style>\n        <link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"../../node_modules/highlight.js/styles/monokai.css\" />\n        <link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"../../node_modules/normalize.css/normalize.css\" />\n    </head>\n    <body>" + body + "</body>\n</html>"; };
if (!fs_1.existsSync("docs/build")) {
    fs_1.mkdirSync("docs/build");
}
var pages = fs_1.readdirSync("docs/pages")
    .filter(function (path) { return path_1.extname(path) === ".md"; })
    .map(function (path) { return path_1.join("docs/pages", path); })
    .map(pageModel_1.PageModel.from);
var orderPath = path_1.join("docs/pages", "order.txt");
var order = [];
if (fs_1.existsSync(orderPath) && !fs_1.statSync(orderPath).isDirectory()) {
    order = fs_1.readFileSync(orderPath, "UTF8").split("\n");
}
function orderBy(order) {
    var getIndex = function (page) {
        if (page.name === "index") {
            return -Infinity;
        }
        var index = order.indexOf(page.name);
        if (index === -1) {
            index = order.indexOf("*");
        }
        return index === -1 ? Infinity : index;
    };
    return function (a, b) {
        var aIndex = getIndex(a);
        var bIndex = getIndex(b);
        if (aIndex < bIndex) {
            return -1;
        }
        else if (aIndex > bIndex) {
            return 1;
        }
        else {
            return a.title.toLowerCase() < b.title.toLowerCase() ? -1 : 1;
        }
    };
}
pages.sort(orderBy(order));
pages.forEach(function (page, index) {
    var body = ReactDOMServer.renderToString(React.createElement(page_1.Page, { pages: pages, pageIndex: index }));
    var title = page.name === "index" ? page.title : page.title + " | Safe Units";
    var html = renderPageHtml(title, body, typestyle_1.getStyles());
    fs_1.writeFileSync(path_1.join("docs/build", page.path), html);
});
//# sourceMappingURL=index.js.map