"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var highlight_js_1 = require("highlight.js");
var React = require("react");
exports.Markdown = function (_a) {
    var root = _a.root;
    switch (root.type) {
        case "document":
            return React.createElement(MarkdownChildren, { root: root });
        case "paragraph":
            var children = React.createElement(MarkdownChildren, { root: root });
            var grandparent = root.parent ? root.parent.parent : null;
            if (grandparent != null && grandparent.type === "list" && grandparent.listTight) {
                return children;
            }
            else {
                return React.createElement("p", null, children);
            }
        case "text":
            return React.createElement(React.Fragment, null, root.literal);
        case "linebreak":
            return React.createElement("br", null);
        case "html_inline":
            return React.createElement("span", { dangerouslySetInnerHTML: { __html: root.literal || "" } });
        case "html_block":
            return React.createElement("span", { dangerouslySetInnerHTML: { __html: root.literal || "" } });
        case "link":
            return (React.createElement("a", { href: root.destination || "" },
                React.createElement(MarkdownChildren, { root: root })));
        case "image":
            return React.createElement("img", { src: root.destination || "", alt: root.title || "" });
        case "thematic_break":
            return React.createElement("hr", null);
        case "code_block":
            var highlightedCode = highlight_js_1.highlight("typescript", root.literal || "", true).value;
            return (React.createElement("pre", null,
                React.createElement("code", { className: "hljs typescript", dangerouslySetInnerHTML: { __html: highlightedCode } })));
        case "code":
            return React.createElement("code", null, root.literal);
        case "softbreak":
            return React.createElement("br", null);
        case "custom_inline":
            // TODO Handle this
            return null;
        case "custom_block":
            // TODO Handle this
            return null;
        default:
            var Tag = getTag(root.type, root);
            return React.createElement(Tag, {}, React.createElement(MarkdownChildren, { root: root }));
    }
};
var MarkdownChildren = function (_a) {
    var root = _a.root;
    var children = [];
    var index = 0;
    var child = root.firstChild;
    while (child !== null) {
        children.push(React.createElement(exports.Markdown, { key: index, root: child }));
        index++;
        child = child.next;
    }
    return React.createElement(React.Fragment, null, children);
};
function getTag(type, node) {
    switch (type) {
        case "emph":
            return "em";
        case "strong":
            return "strong";
        case "block_quote":
            return "blockquote";
        case "item":
            return "li";
        case "list":
            return node.listType === "bullet" ? "ul" : "ol";
        case "heading":
            switch (node.level) {
                case 1:
                    return "h1";
                case 2:
                    return "h2";
                case 3:
                    return "h3";
                case 4:
                    return "h4";
                case 5:
                    return "h5";
                case 6:
                    return "h6";
                default:
                    return "h6";
            }
    }
}
//# sourceMappingURL=markdown.js.map