"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var commonmark_1 = require("commonmark");
var fs_1 = require("fs");
var path_1 = require("path");
var markdown_1 = require("../common/markdown");
var PageModel = /** @class */ (function () {
    function PageModel(name, root, title) {
        this.name = name;
        this.root = root;
        this.title = title;
    }
    PageModel.from = function (path) {
        var name = path_1.basename(path, ".md");
        var source = fs_1.readFileSync(path, "UTF8");
        var root = parser.parse(source);
        var title = getTitle(root);
        return new PageModel(name, parser.parse(source), title);
    };
    Object.defineProperty(PageModel.prototype, "path", {
        get: function () {
            return this.name + ".html";
        },
        enumerable: true,
        configurable: true
    });
    return PageModel;
}());
exports.PageModel = PageModel;
function getTitle(root) {
    var fallback = "Untitled";
    var walker = root.walker();
    var maybeDocument = markdown_1.nextStep(walker);
    if (maybeDocument === null || maybeDocument.node.type !== "document") {
        return fallback;
    }
    var maybeHeading = markdown_1.nextStep(walker);
    if (maybeHeading === null || maybeHeading.node.type !== "heading" || maybeHeading.node.level !== 1) {
        return fallback;
    }
    return markdown_1.getNodeText(maybeHeading.node);
}
var parser = new commonmark_1.Parser();
//# sourceMappingURL=pageModel.js.map